@@ -115,7 +115,7 @@ from obitools import NucSequence, DNAComplementSequence
 from string import lower
 
 import sys
-
+  
 import math
 
 from obitools.options import getOptionManager
@@ -127,26 +127,6 @@ from obitools.format.options import addInOutputOption, sequenceWriterGenerator
 
 def addNGSOptions(optionManager):
     
-#    optionManager.add_option('-d','--direct',
-#                             action="store", dest="direct",
-#                             metavar="<PRIMER SEQUENCE>",
-#                             type="string",
-#                             default=None,
-#                             help="sequence of the direct primer")
-#
-#    optionManager.add_option('-r','--reverse',
-#                             action="store", dest="reverse",
-#                             metavar="<PRIMER SEQUENCE>",
-#                             type="string",
-#                             default=None,
-#                             help="sequence of the reverse primer")
-#
-#    optionManager.add_option('-l','--tag-length',
-#                             action="store", dest="taglength",
-#                             metavar="###",
-#                             type="int",
-#                             default=None,
-#                             help="length of the tag")
 
     optionManager.add_option('-t','--tag-list',
                              action="store", dest="taglist",
@@ -155,11 +135,6 @@ def addNGSOptions(optionManager):
                              default=None,
                              help="file containing tag used")
     
-#    optionManager.add_option('-1','--one-tag',
-#                             action="store_true", dest="onetag",
-#                             default=False,
-#                             help="Assert than only one tag in present on the direct primer")
-    
     optionManager.add_option('-u','--unidentified',
                              action="store", dest="unidentified",
                              metavar="<FILENAME>",
@@ -202,7 +177,10 @@ class Primer:
         self.align.mismatch=-2
         self.align.opengap=-2
         self.align.extgap=-2
-        self.minscore = self.lseq * self.align.match + error * self.align.mismatch
+        self.error=error
+        self.minscore = (self.lseq-error) * self.align.match + error * self.align.mismatch
+        if verbose:
+            print >>sys.stderr,sequence,":",self.lseq,"*",self.align.match,"+",error,"*",self.align.mismatch,"=",self.minscore
         self.taglength=taglength
         
         self.align.seqB=self.sequence
@@ -213,7 +191,8 @@ class Primer:
     def complement(self):
         p = Primer(self.raw,
                   self.taglength,
-                  not self.direct)
+                  not self.direct,verbose=self.verbose,
+                  error=self.error)
         p.sequence=p.sequence.complement()
         p.align.seqB=p.sequence
         return p
@@ -227,10 +206,10 @@ class Primer:
     def __call__(self,sequence):
         if len(sequence) <= self.lseq:
             return None
-        #print >>sys.stderr,len(sequence) , self.lseq,len(sequence) < self.lseq
+        if self.verbose:
+            print >>sys.stderr,len(sequence) , self.lseq,len(sequence) < self.lseq
         self.align.seqA=sequence
         ali=self.align()
-        
         if self.verbose:
             print >>sys.stderr,ali
             print >>sys.stderr,"Score : %d  Minscore : %d \n" %(ali.score,self.minscore)
@@ -295,7 +274,7 @@ def readTagfile(filename):
         forward=Primer(p['forward_primer'],
                        len(p['tags'][0]) if p['tags'][0]!='-' else None,
                        True,
-                       error=options.error)
+                       error=options.error,verbose=options.debug)
         
         fp = primers.get(forward,{})
         primers[forward]=fp
@@ -303,15 +282,13 @@ def readTagfile(filename):
         reverse=Primer(p['reverse_primer'],
                        len(p['tags'][1]) if p['tags'][1]!='-' else None,
                        False,
-                       error=options.error)
+                       error=options.error,verbose=options.debug)
         
         rp = primers.get(reverse,{})
         primers[reverse]=rp
         
         cf=forward.complement()
-#        cf.verbose=True
         cr=reverse.complement()
-#        cr.verbose=True
         
         dpp=fp.get(cr,{})
         fp[cr]=dpp
@@ -379,13 +356,16 @@ def annotate(sequence,options):
         sequence['tail_quality']=q
         
     primers = options.primers
+    if options.debug:
+        print >>sys.stderr,"directmatch"
     directmatch = [(p,p(sequence)) for p in primers]
     
-    #print directmatch
     
     directmatch.sort(cmp=sortMatch)
     directmatch=directmatch[0] if directmatch[0][1] is not None else None
     
+    if options.debug:
+        print  >>sys.stderr,">>>>",directmatch
     if directmatch is None:
         sequence['error']='No primer match'
         return False,sequence
@@ -411,16 +391,19 @@ def annotate(sequence,options):
     del sequence['cut']
     
     primers = options.primers[directmatch[0]]
+    if options.debug:
+        print  >>sys.stderr,"reverse match"
     reversematch = [(p,p(sequence)) for p in primers if p is not None]
     reversematch.sort(cmp=sortMatch)
     reversematch = reversematch[0] if reversematch[0][1] is not None else None
     
+    if options.debug:
+        print  >>sys.stderr,"<<<<",reversematch
     if reversematch is None and None not in primers:
         if directmatch[0].direct:
             message = 'No reverse primer match'
         else:
             message = 'No direct primer match'
-            sequence=sequence.complement()
                   
         sequence['error']=message
         return False,sequence
