@@ -1,5 +1,21 @@
 #!/usr/local/bin/python
+"""
+:py:mod:`obicomplement` : Reverse complement sequences 
+======================================================
 
+.. codeauthor:: Eric Coissac <eric.coissac@metabarcoding.org>
+
+:py:mod:`obicomplement` allows to reverse complement the sequences in a file.
+
+Note that the identifiers 'ID' of the sequences are modified and are of the form 'ID_CMP'.
+
+Example: 
+.. code-block:: bash
+
+   > obicomplement seq.fasta > seqRC.fasta
+
+
+"""
 
 from obitools.options import getOptionManager
 from obitools.options.bioseqfilter import addSequenceFilteringOptions
@@ -9,7 +25,7 @@ from obitools.format.options import addInOutputOption, sequenceWriterGenerator
 
 if __name__=='__main__':
     
-    optionParser = getOptionManager([addSequenceFilteringOptions,addInOutputOption])
+    optionParser = getOptionManager([addSequenceFilteringOptions,addInOutputOption], progdoc=__doc__)
     
     (options, entries) = optionParser()
     
