@@ -1,9 +1,22 @@
 #!/usr/local/bin/python
 '''
-Created on 15 dec. 2009
+:py:mod:`obitail` : Extract the last sequences
+==============================================
+
+.. codeauthor:: Eric Coissac <eric.coissac@metabarcoding.org>
+
+:py:mod:`obitail` command is in some way analog to the standard Unix `tail` command.
+It selects the tail of :ref:`a sequence file<the-sequence-files>`. 
+But instead of working text line by text line as the standard tool, 
+selection is done at sequence level. You can specify number of sequences to be printed.
+
+.. code-block:: bash
+
+   > obitail -n 150 seq1.fasta > seq2.fasta
+
 
-@author: coissac
 '''
+
 from obitools.format.options import addInOutputOption, sequenceWriterGenerator
 from obitools.options import getOptionManager
 import collections
