@@ -1,11 +1,13 @@
 import struct
 import sys
 
-from itertools import count,imap
+from itertools import count,imap,combinations
 
 from obitools.ecopcr import EcoPCRDBFile
 from obitools.utils import universalOpen
 from obitools.utils import ColumnFile
+import math
+from collections import Counter
 
 class Taxonomy(object):
     def __init__(self):
@@ -116,11 +118,43 @@ class Taxonomy(object):
             
         return ancetre
     
-    def betterCommonTaxon(self,error=1,*taxids):
-        lca = self.lastCommonTaxon(*taxids)
-        idx = self._index[lca]
-        sublca = [t[0] for t in self._taxonomy if t[2]==idx]
-        return sublca
+    def depth(self,taxid):
+        return len([x for x in self.parentalTreeIterator(taxid)])
+    
+    def betterCommonTaxon(self,error=0.2,*taxids): 
+
+        def permanentIterator(x):
+            for i in x:
+                yield i
+            while(1):
+                yield None
+                    
+        taxids = set(taxids)
+        
+        if len(taxids)==1: return taxids.pop()
+        
+
+        allLineage = [[x[0] for x in self.parentalTreeIterator(y)]
+                      for y in taxids]
+        
+        for x in allLineage: x.reverse()
+        
+        allLineage=[permanentIterator(x) for x in allLineage]
+        
+        c=True
+        while(c):
+            
+            lcas = Counter([x.next() for x in allLineage])
+            #print lcas
+            if len(lcas) > 1:
+                main = float(max(lcas.values()))/len(taxids)
+                c = main > (1 - error)
+            if c:
+                lca = lcas.most_common(1)[0][0]
+
+        #print lca
+           
+        return lca
 
     
     def getPreferedName(self,taxid):
