@@ -14,8 +14,7 @@ def addUniqOptions(optionManager):
                              metavar="<TAG NAME>",
                              type="string",
                              default=[],
-                             help="ecoPCR taxonomy Database "
-                                  "name")
+                             help="attributes to merge")
     
     optionManager.add_option('-c','--category-attribute',
                              action="append", dest="categories",
